@@ -21,7 +21,6 @@ from yellowdog_client.model import (
 
 from yd_commands.config_types import ConfigWorkerPool
 from yd_commands.follow_utils import follow_ids
-from yd_commands.id_utils import YDIDType, get_ydid_type
 from yd_commands.load_config import CONFIG_FILE_DIR, load_config_worker_pool
 from yd_commands.printing import (
     print_error,
@@ -117,6 +116,8 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
             wp_json_file, prefix=WP_VARIABLES_PREFIX, postfix=WP_VARIABLES_POSTFIX
         )
 
+    _update_node_counts()
+
     # Some values are configurable via the TOML configuration file;
     # values in the JSON file override values in the TOML file
     try:
@@ -237,10 +238,6 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
     except KeyError as e:
         raise Exception(f"Key error in JSON Worker Pool definition: {e}")
 
-    template_id = wp_data["requirementTemplateUsage"]["templateId"]
-    if get_ydid_type(template_id) != YDIDType.CR_TEMPLATE:
-        raise Exception(f"Not a valid Compute Requirement Template ID: '{template_id}'")
-
     if ARGS_PARSER.dry_run:
         print_log("Dry-run: Printing JSON Worker Pool specification")
         print_yd_object(wp_data)
@@ -255,7 +252,9 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
     name = wp_data["requirementTemplateUsage"]["requirementName"]
     if response.status_code == 200:
         id = response.json()["id"]
-        print_log(f"Provisioned Worker Pool '{name}' ({id})")
+        print_log(
+            f"Provisioned Worker Pool '{reqt_template_usage['requirementNamespace']}/{name}' ({id})"
+        )
         if ARGS_PARSER.quiet:
             print(id)
         if ARGS_PARSER.follow:
@@ -271,30 +270,13 @@ def create_worker_pool_from_toml():
     Create the Worker Pool
     """
 
-    global CONFIG_WP
-
-    # Check for well-configured node quantities
-    if not (
-        CONFIG_WP.min_nodes <= CONFIG_WP.target_instance_count <= CONFIG_WP.max_nodes
-        and CONFIG_WP.max_nodes > 0
-    ):
-        print_error(
-            "Please ensure that minNodes <= targetInstanceCount <= maxNodes"
-            " and maxNodes >= 1"
-        )
-        raise Exception("Malformed configuration")
+    _update_node_counts()
 
     # Allow the Compute Requirement Template name to be used instead of ID
     CONFIG_WP.template_id = get_template_id(
         client=CLIENT, template_id_or_name=CONFIG_WP.template_id
     )
 
-    if get_ydid_type(CONFIG_WP.template_id) != YDIDType.CR_TEMPLATE:
-        raise Exception(
-            "Not a valid Compute Requirement Template ID or name:"
-            f" '{CONFIG_WP.template_id}'"
-        )
-
     # Allow the Image Family name to be used instead of ID
     if CONFIG_WP.images_id is not None:
         CONFIG_WP.images_id = get_image_family_id(
@@ -340,7 +322,7 @@ def create_worker_pool_from_toml():
     # Create the Worker Pool
     print_log(
         f"Provisioning {CONFIG_WP.target_instance_count:,d} node(s) "
-        f"with {node_workers.targetCount:,d} worker(s) per "
+        f"with {node_workers.targetCount:.1f} worker(s) per "
         f"{node_workers.targetType} "
         f"(minNodes: {CONFIG_WP.min_nodes:,d}, "
         f"maxNodes: {CONFIG_WP.max_nodes:,d})"
@@ -365,13 +347,13 @@ def create_worker_pool_from_toml():
         )
         if num_batches > 1:
             print_log(
-                f"Provisioning Worker Pool {batch_number + 1} '{id}' "
+                f"Provisioning Worker Pool {batch_number + 1} '{CONFIG_COMMON.namespace}/{id}' "
                 f"with {batches[batch_number].initial_nodes:,d} nodes(s) "
                 f"(minNodes: {batches[batch_number].min_nodes:,d}, "
                 f"maxNodes: {batches[batch_number].max_nodes:,d})"
             )
         else:
-            print_log(f"Provisioning Worker Pool '{id}'")
+            print_log(f"Provisioning Worker Pool '{CONFIG_COMMON.namespace}/{id}'")
         try:
             compute_requirement_template_usage = ComputeRequirementTemplateUsage(
                 templateId=CONFIG_WP.template_id,
@@ -491,6 +473,53 @@ def _allocate_nodes_to_batches(
     return batches
 
 
+def _update_node_counts():
+    """
+    Tidy up node counts.
+    """
+    global CONFIG_WP
+
+    # Automatically increase targetInstanceCount if required
+    if CONFIG_WP.target_instance_count < 0:
+        print_log(
+            f"Increasing 'targetInstanceCount' from {CONFIG_WP.target_instance_count} "
+            "to 0 to satisfy minimum constraint"
+        )
+        CONFIG_WP.target_instance_count = 0
+
+    # Automatically increase maxNodes if required
+    if CONFIG_WP.target_instance_count > CONFIG_WP.max_nodes:
+        print_log(
+            f"Increasing 'maxNodes' from {CONFIG_WP.max_nodes} to "
+            f"{CONFIG_WP.target_instance_count} to match 'targetInstanceCount'"
+        )
+        CONFIG_WP.max_nodes = CONFIG_WP.target_instance_count
+
+    # Automatically set maxNodes to 1 if required
+    if CONFIG_WP.max_nodes < 1:
+        print_log(
+            f"Increasing 'maxNodes' from {CONFIG_WP.max_nodes} to 1 to satisfy "
+            "minimum constraint"
+        )
+        CONFIG_WP.max_nodes = 1
+
+    # Automatically reduce minNodes if required
+    if CONFIG_WP.target_instance_count < CONFIG_WP.min_nodes:
+        print_log(
+            f"Reducing 'minNodes' from {CONFIG_WP.min_nodes} to "
+            f"{CONFIG_WP.target_instance_count} to match 'targetInstanceCount'"
+        )
+        CONFIG_WP.min_nodes = CONFIG_WP.target_instance_count
+
+    # Automatically set minNodes to 0 if required
+    if CONFIG_WP.min_nodes < 0:
+        print_log(
+            f"Increasing 'minNodes' from {CONFIG_WP.min_nodes} to 0 to satisfy "
+            "minimum constraint"
+        )
+        CONFIG_WP.min_nodes = 0
+
+
 # Entry point
 if __name__ == "__main__":
     main()
